@@ -1,6 +1,6 @@
 
 
-from kivy.uix.boxlayout import BoxLayout
+from kivy_garden.ebs.core.colors import ColorBoxLayout
 from ebs.linuxnode.core.background import BackgroundProviderBase
 from ebs.linuxnode.gui.kivy.mediaplayer.manager import KivyMediaPlayerManager
 from ebs.linuxnode.mediaplayer.manager import BACKGROUND
@@ -9,6 +9,7 @@ from ebs.linuxnode.mediaplayer.manager import BACKGROUND
 class MediaPlayerBackgroundProvider(BackgroundProviderBase):
     def __init__(self, actual):
         super(MediaPlayerBackgroundProvider, self).__init__(actual)
+        self._widget = None
         self._mpm = KivyMediaPlayerManager(actual, BACKGROUND, self.widget)
         self.actual.install_media_player_manager(self._mpm)
 
@@ -25,7 +26,7 @@ class MediaPlayerBackgroundProvider(BackgroundProviderBase):
         d = self._mpm.play(target, duration=duration, **kwargs)
         if callback:
             d.addBoth(callback)
-        return self._widget
+        return self.widget
 
     def stop(self):
         self._mpm.stop()
@@ -39,5 +40,5 @@ class MediaPlayerBackgroundProvider(BackgroundProviderBase):
     @property
     def widget(self):
         if not self._widget:
-            self._widget = BoxLayout()
+            self._widget = ColorBoxLayout(bgcolor=(0.4, 0.4, 0.4, 1))
         return self._widget
